# Copyright (c) 2000-2009, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with test
%bcond_with bootstrap

%define gcj_support %{?_with_gcj_support:1}%{!?_with_gcj_support:%{?_without_gcj_support:0}%{!?_without_gcj_support:%{?_gcj_support:%{_gcj_support}}%{!?_gcj_support:0}}}

%define section free

Name:           xom
Version:        1.2.1
Release:        1%{?dist}
Epoch:          0
Summary:        XML Pull Parser
License:        LGPLv2+
URL:            http://www.xom.nu/
Group:          Text Processing/Markup/XML
Source0:        http://www.cafeconleche.org/XOM/xom-1.2.1-src.tar.gz
Source1:        http://repo1.maven.org/maven2/xom/xom/1.2.1/xom-1.2.1.pom
Patch0:         xom-1.2.1-remove-jaxen.patch
Patch1:         xom-1.1-clean-dist.patch
Patch2:         xom-1.1-compile15.patch
Patch3:         xom-1.1-remove_sun_import.patch
Patch4:         xom-1.2b2-crosslink.patch
Patch5:         xom-1.1-sinjdoc.patch
Patch6:         xom-1.2b2-javadoc-stack-size.patch
BuildRequires:  java-devel >= 0:1.5
BuildRequires:  ant >= 0:1.6
BuildRequires:  ant-junit
BuildRequires:  java-javadoc
BuildRequires:  jaxen
BuildRequires:  junit
BuildRequires:  junit-javadoc
BuildRequires:  xalan-j2
BuildRequires:  xerces-j2
BuildRequires:  icu4j
BuildRequires:  xml-commons-jaxp-1.3-apis

%if %without bootstrap
BuildRequires:  tagsoup
BuildRequires:  saxon
BuildRequires:  jaxp_parser_impl
BuildRequires:  xml-commons-resolver12
BuildRequires:  servlet
%endif
Requires:       xalan-j2
Requires:       xerces-j2
Requires:       icu4j
Requires:       xml-commons-jaxp-1.3-apis
%if !%{gcj_support}
BuildArch:      noarch
BuildRequires:  java-devel
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%endif

%description
XOM is a new XML object model. It is an open source (LGPL), 
tree-based API for processing XML with Java that strives 
for correctness, simplicity, and performance, in that order. 
XOM is designed to be easy to learn and easy to use. It 
works very straight-forwardly, and has a very shallow 
learning curve. Assuming you're already familiar with XML, 
you should be able to get up and running with XOM very quickly.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description javadoc
%{summary}.

%if %without bootstrap
%package demo
Summary:        Samples for %{name}
Group:          Development/Documentation
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description demo
%{summary}.
%endif

%prep
%setup -q -n XOM
# remove all binary libs
%{_bindir}/find . -name "*.jar" -o -name "*.class" | %{_bindir}/xargs -t %{__rm}
%patch0 -p0
%patch1 -p0
%patch2 -p1
%patch3 -p1
%patch4 -p1
# XXX: (dwalluck): Required only for sinjdoc
%if 0
%patch5 -p1
%endif
%patch6 -p1
%{__perl} -pi -e 's/\r$//g' *.html *.txt
%{__perl} -pi -e 's/compress="no"/compress="yes"/g' build.xml

%build
export CLASSPATH=$(build-classpath jaxen)
export OPT_JAR_LIST="junit ant/ant-junit"
export ANT_OPTS="-Xss1m"
pushd lib
ln -sf $(build-classpath junit) junit.jar
ln -sf $(build-classpath xerces-j2) xercesImpl.jar
ln -sf $(build-classpath xalan-j2) xalan.jar
ln -sf $(build-classpath icu4j) normalizer.jar
ln -sf $(build-classpath xml-commons-jaxp-1.3-apis) xmlParserAPIs.jar
popd
mkdir lib2
%if %without bootstrap
pushd lib2
ln -sf $(build-classpath tagsoup) tagsoup-1.0rc1.jar
ln -sf $(build-classpath saxon) saxon.jar
ln -sf $(build-classpath jaxp_parser_impl) gnujaxp.jar
ln -sf $(build-classpath xml-commons-resolver12) resolver.jar
DOM4J_PRESENT=$(build-classpath dom4j 2>/dev/null || :)
if [ -n "$DOM4J_PRESENT" ]; then
ln -sf $(build-classpath dom4j) dom4j-1.5.1.jar
fi
ln -sf $(build-classpath servlet) servlet.jar
popd
%endif

ant -Dbuild.sysclasspath=first -Dj2se.api=%{_javadocdir}/java -Djunit.api=%{_javadocdir}/junit jar javadoc
%if %without bootstrap
ant -Dbuild.sysclasspath=first samples
%if %with test
ant -Dbuild.sysclasspath=first test
%endif
%endif

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -m 644 build/xom-%{version}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# poms
%add_to_maven_depmap %{name} %{name} %{version} JPP %{name}
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/maven2/poms
install -pm 644 %{SOURCE1} \
    $RPM_BUILD_ROOT%{_datadir}/maven2/poms/JPP-%{name}.pom

# javadoc
install -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -a build/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}

%if %without bootstrap
# demo
install -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}
install -m 644 build/xom-samples.jar $RPM_BUILD_ROOT%{_datadir}/%{name}
install -m 644 xom.graffle $RPM_BUILD_ROOT%{_datadir}/%{name}
%endif

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)
%doc overview.html README.txt LICENSE.txt Todo.txt lgpl.txt
%if %without bootstrap
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/xom.graffle
%endif
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-%{version}.jar
%{_datadir}/maven2/poms/*
%{_mavendepmapfragdir}/*
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}

%if %without bootstrap
%files demo
%defattr(0644,root,root,0755)
%{_datadir}/%{name}/xom-samples.jar
%endif

%changelog
* Tue Mar 10 2009 David Walluck <dwalluck@redhat.com> 0:1.2.1-1
- 1.2.1

* Wed Aug 06 2008 David Walluck <dwalluck@redhat.com> 0:1.2-0.b2.4
- add crosslink patch

* Wed Aug 06 2008 David Walluck <dwalluck@redhat.com> 0:1.2-0.b2.3
- add ANT_OPTS and patch for javac and javadoc stack size, respectively

* Mon Aug 04 2008 David Walluck <dwalluck@redhat.com> 0:1.2-0.b2.2
- add maven support

* Mon Aug 04 2008 David Walluck <dwalluck@redhat.com> 0:1.2-0.b2.1
- 1.2b2

* Mon Aug 04 2008 David Walluck <dwalluck@redhat.com> 0:1.1-5
- BuildRequires: dom4j
- BuildRequires: saxon7
- don't use classpathx-jaxp

* Tue Jul 29 2008 David Walluck <dwalluck@redhat.com> 0:1.1-4
- fix License

* Sat Jul 26 2008 David Walluck <dwalluck@redhat.com> 0:1.1-3
- remove spurious BuildRequires: classpathx-jaxp
- remove javadoc scriptlets
- update License
- update BuildRoot
- GCJ fixes
- properly unpack sources
- fix maven directory ownership
- add ant-junit to OPT_JAR_LIST
- add ant-trax to OPT_JAR_LIST

* Tue Jun 24 2008 Fernando Nasser <fnasser@redhat.com> - 0:1.1-2
- Add missing dependency on ant-trax

* Thu Jan 31 2008 Ralph Apel <r.apel at r-apel.de> - 0:1.1-1jpp
- 1.1
- Add pom and depmap frags

* Wed May 09 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.0-5jpp
- Make Vendor, Distribution based on macro

* Mon Feb 12 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.0-4jpp
- Add option to build core on bootstrap
- Add gcj_support option

* Tue Feb 28 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0-3jpp
- Remove dependency on clover10 (non-free)

* Sun Feb 26 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.0-2jpp
- First JPP 1.7 release

* Wed Aug 17 2005 Ralph Apel <r.apel at r-apel.de> - 0:1.0-1jpp
- First JPP release
